@@ -24,10 +24,10 @@ def prepend_to_path(d):
     
 def update_path_for_stempy():
     d = os.path.dirname(__file__)
-    prepend_to_path(os.path.normpath(os.path.join(d, '..', '..', '..', '..', 'Infpy', 'python'))) # Infpy
-    prepend_to_path(os.path.normpath(os.path.join(d, '..', '..', '..', '..', 'PyICL', 'Python'))) # PyICL
-    prepend_to_path(os.path.normpath(os.path.join(d, '..', '..', '..', '..', 'Python', 'Cookbook', 'python'))) # cookbook
-    prepend_to_path(os.path.normpath(os.path.join(d, '..', '..'))) # stempy
+#     prepend_to_path(os.path.normpath(os.path.join(d, '..', '..', '..', '..', 'Infpy', 'python'))) # Infpy
+#     prepend_to_path(os.path.normpath(os.path.join(d, '..', '..', '..', '..', 'PyICL', 'Python'))) # PyICL
+#     prepend_to_path(os.path.normpath(os.path.join(d, '..', '..', '..', '..', 'Python', 'Cookbook', 'python'))) # cookbook
+#     prepend_to_path(os.path.normpath(os.path.join(d, '..', '..'))) # stempy
     #print sys.path
 
 def fasta_dir():
