@@ -9,9 +9,8 @@ Test read sequences.
 #
 # Trickery to find update path to import stempy from
 #
-from setup_environment import init_test_env, update_path_for_stempy, fasta_dir
+from setup_environment import init_test_env, fasta_dir
 init_test_env(__file__)
-update_path_for_stempy()
 
 import stempy, os
 from cookbook.named_tuple import namedtuple
