@@ -6,9 +6,8 @@
 Test find starts.
 """
 
-from setup_environment import init_test_env, update_path_for_stempy, fasta_dir
+from setup_environment import init_test_env, fasta_dir
 init_test_env(__file__)
-update_path_for_stempy()
 
 import stempy, os
 
