@@ -6,9 +6,8 @@
 Test STEME makes correct log odds matrices.
 """
 
-from setup_environment import init_test_env, update_path_for_stempy, logging
+from setup_environment import init_test_env, logging
 init_test_env(__file__, level=logging.INFO)
-update_path_for_stempy()
 
 import stempy, numpy
 from itertools import imap
