@@ -1,18 +1,18 @@
 #
-# Copyright John Reid 2010, 2011
+# Copyright John Reid 2010, 2011, 2012, 2013
 #
 
 """
 Test read sequences.
 """
 
-from setup_environment import init_test_env, update_path_for_stempy, fasta_dir
+from setup_environment import init_test_env, fasta_dir
 init_test_env(__file__)
-update_path_for_stempy()
 
 import stempy, os
 
 options = stempy.get_default_options()
+options.cache_index = True
 
 # check reading in correct amount of data
 fasta_file = os.path.join(fasta_dir(), 'find-starts-test.fa')
@@ -22,3 +22,4 @@ assert len(seqs) == 2
 assert '75' in ids
 assert '76' in ids
 assert 2 == len(ids)
+
