@@ -6,9 +6,8 @@
 Test STEME on data from Hemant.
 """
 
-from setup_environment import init_test_env, update_path_for_stempy, logging
+from setup_environment import init_test_env, logging
 init_test_env(__file__, level=logging.INFO)
-update_path_for_stempy()
 
 import os, sys, stempy
 
