@@ -9,9 +9,8 @@ Test STEME motif spacing functionality.
 # do this first as otherwise have strange segmentation violation. Not sure of reason for this
 import scipy.special
 
-from setup_environment import init_test_env, update_path_for_stempy, logging
+from setup_environment import init_test_env, logging
 init_test_env(__file__, level=logging.INFO)
-update_path_for_stempy()
 
 import pkg_resources
 from optparse import OptionParser
