@@ -6,9 +6,8 @@
 Test STEME's performance on some small data sets of random sequences with planted sites.
 """
 
-from setup_environment import init_test_env, update_path_for_stempy, logging, fasta_dir, is_debug_python
+from setup_environment import init_test_env, logging, fasta_dir, is_debug_python
 init_test_env(__file__, level=logging.INFO)
-update_path_for_stempy()
 
 import stempy, os
 from stempy.planted_sites import parse_fasta_for_sites, parse_meme_output_for_sites, calculate_positives_and_negatives
@@ -36,7 +35,7 @@ else:
         ('random-seqs-with-Ns-05-100', .60, .90),
         ('random-seqs-05-100'        , .40, .89), # cannot achieve (.6,.9) stats when finding starts up-front
         ('random-seqs-10-100'        , .60, .91),
-        ('random-seqs-with-Ns-10-100', .20, .99),
+        ('random-seqs-with-Ns-10-100', .20, .98), # lower specificity with Ns
         ('random-seqs-30-200'        , .46, .99),
         ('random-seqs-with-Ns-30-200', .46, .99),
     ]
