@@ -6,9 +6,8 @@
 Test STEME's performance on some small data sets of random sequences with planted sites.
 """
 
-from setup_environment import init_test_env, update_path_for_stempy, logging, fasta_dir
+from setup_environment import init_test_env, logging, fasta_dir
 init_test_env(__file__, level=logging.INFO)
-update_path_for_stempy()
 
 import stempy, os
 from stempy.planted_sites import parse_meme_output_for_sites
